@@ -42,7 +42,7 @@ class BaseSchema(BaseModel):
         return super().__init_subclass__()
 
     @classmethod
-    def register_datasource(cls, datasource, name='data'):
+    def register_datasource(cls, datasource, name='data', initialize=False):
         """Register a datasource with this schema
         """
 
@@ -51,7 +51,7 @@ class BaseSchema(BaseModel):
             
         from rframe.data_accessor import DataAccessor
 
-        accessor = DataAccessor(cls, datasource)
+        accessor = DataAccessor(cls, datasource, initdb=initialize)
         setattr(cls, name, accessor)
 
     @classmethod
@@ -401,7 +401,7 @@ class BaseSchema(BaseModel):
             # Single document found, update
             try:
                 existing[0].__pre_update(datasource, self)
-                interface.update(self)
+                interface.update(existing[0].index_labels , self)
             except Exception as e:
                 existing[0].__post_update(datasource, self, exception=e)
                 raise e
